summaryrefslogtreecommitdiff
path: root/plugins/FingerprintNG/src
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2021-12-26 16:39:04 +0300
committerGeorge Hazan <ghazan@miranda.im>2021-12-26 16:39:04 +0300
commit62a186697df33c96dc1a6dac0f4dfc38652fb96f (patch)
tree1437d0906218fae8827aed384026f2b7e656f4ac /plugins/FingerprintNG/src
parentfcbb395dc7ff3edab972b6d4b27dbbfb3305f5d7 (diff)
BYTE -> uint8_t
Diffstat (limited to 'plugins/FingerprintNG/src')
-rw-r--r--plugins/FingerprintNG/src/fingerprint.cpp8
-rw-r--r--plugins/FingerprintNG/src/options.cpp2
-rw-r--r--plugins/FingerprintNG/src/stdafx.h8
3 files changed, 9 insertions, 9 deletions
diff --git a/plugins/FingerprintNG/src/options.cpp b/plugins/FingerprintNG/src/options.cpp
index 9c6852998a..f9bd46944f 100644
--- a/plugins/FingerprintNG/src/options.cpp
+++ b/plugins/FingerprintNG/src/options.cpp
@@ -59,7 +59,7 @@ class COptDialog : public CDlgBase
m_chkFacebbok, m_chkGG, m_chkICQ, m_chkIRC, m_chkJabber, m_chkRSS, m_chkVK, m_chkWeather, m_chkMulti, m_chkOthersProto,
m_chkOthers, m_chkStatusBar;
- void LoadDBCheckState(int idCtrl, LPCSTR szSetting, BYTE bDef)
+ void LoadDBCheckState(int idCtrl, LPCSTR szSetting, uint8_t bDef)
{
CCtrlCheck &item = *(CCtrlCheck*)FindControl(idCtrl);
item.SetState(g_plugin.getByte(szSetting, bDef));
diff --git a/plugins/FingerprintNG/src/stdafx.h b/plugins/FingerprintNG/src/stdafx.h
index e25cb6ae39..5c18b48fc9 100644
--- a/plugins/FingerprintNG/src/stdafx.h
+++ b/plugins/FingerprintNG/src/stdafx.h
@@ -47,10 +47,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
struct RGBA
{
- BYTE b;
- BYTE g;
- BYTE r;
- BYTE a;
+ uint8_t b;
+ uint8_t g;
+ uint8_t r;
+ uint8_t a;
};
struct KN_FP_MASK
diff --git a/plugins/FingerprintNG/src/fingerprint.cpp b/plugins/FingerprintNG/src/fingerprint.cpp
index dce300cd1c..4302d48ab2 100644
--- a/plugins/FingerprintNG/src/fingerprint.cpp
+++ b/plugins/FingerprintNG/src/fingerprint.cpp
@@ -430,7 +430,7 @@ HBITMAP __fastcall CreateBitmap32Point(int cx, int cy, LPVOID* bits)
}
/*
* checkHasAlfa - checks if image has at least one BYTE in alpha channel
* that is not a 0. (is image real 32 bit or just 24 bit)
*/
BOOL __fastcall checkHasAlfa(LPBYTE from, int width, int height)
@@ -477,8 +477,8 @@ DWORD __fastcall blend(DWORD X1, DWORD X2)
{
RGBA* q1 = (RGBA*)&X1;
RGBA* q2 = (RGBA*)&X2;
- BYTE a_1 = ~q1->a;
- BYTE a_2 = ~q2->a;
+ uint8_t a_1 = ~q1->a;
+ uint8_t a_2 = ~q2->a;
WORD am = q1->a * a_2;
WORD ar = q1->a + ((a_1 * q2->a) / 255);
@@ -511,7 +511,7 @@ HICON __fastcall CreateJoinedIcon(HICON hBottom, HICON hTop)
HBITMAP nMask, hbm, obmp, obmp2;
LPBYTE ptPixels = nullptr;
ICONINFO iNew = { 0 };
- BYTE p[32] = { 0 };
+ uint8_t p[32] = { 0 };
tempDC = CreateCompatibleDC(nullptr);
nImage = CreateBitmap32Point(16, 16, (LPVOID*)&ptPixels);
@@ -430,7 +430,7 @@ HBITMAP __fastcall CreateBitmap32Point(int cx, int cy, LPVOID* bits)
}
/*
-* checkHasAlfa - checks if image has at least one BYTE in alpha channel
+* checkHasAlfa - checks if image has at least one uint8_t in alpha channel
* that is not a 0. (is image real 32 bit or just 24 bit)
*/